@@ -33,23 +33,26 @@
 use crate::tests::{assert_decision, context};
 
 lazy_static! {
-  static ref DEFINITIONS: dmntk_model::model::Definitions = dmntk_model::parse(dmntk_examples::DMN_2_0114, "file: ///2_0114.dmn").unwrap();
+  static ref DEFINITIONS: dmntk_model::model::Definitions = dmntk_model::parse(dmntk_examples::DMN_3_0031, "file: ///3_0031.dmn").unwrap();
 }
 
 #[test]
+#[ignore]
 fn _0001() {
-  let ctx = context(r#"{NumOfYears: 5}"#);
-  assert_decision(&DEFINITIONS, "CarInsurance", &ctx, r#"64.32"#);
+  let ctx = context(r#"{}"#);
+  assert_decision(&DEFINITIONS, "fn invocation positional parameters", &ctx, r#""#);
 }
 
 #[test]
+#[ignore]
 fn _0002() {
-  let ctx = context(r#"{NumOfYears: 3}"#);
-  assert_decision(&DEFINITIONS, "CarInsurance", &ctx, r#"98.83"#);
+  let ctx = context(r#"{}"#);
+  assert_decision(&DEFINITIONS, "fn invocation named parameters", &ctx, r#""#);
 }
 
 #[test]
+#[ignore]
 fn _0003() {
-  let ctx = context(r#"{NumOfYears: 4}"#);
-  assert_decision(&DEFINITIONS, "CarInsurance", &ctx, r#"98.83"#);
+  let ctx = context(r#"{}"#);
+  assert_decision(&DEFINITIONS, "fn invocation complex parameters", &ctx, r#""#);
 }
